Installation
============

.. contents::
   :depth: 3
   :backlinks: entry
   :local:

Requirements
------------

Snakecdysis requires |PythonVersions| and a snakemake workflow to wrapped.

Some wrapped workflow exemples:

- https://culebront-pipeline.readthedocs.io/
- https://rattlesnp.readthedocs.io
- https://podiumasm.readthedocs.io/en/latest/


------------------------------------------------------------------------

Install Snakecdysis PyPI package
--------------------------------

First, install the Snakecdysis python package with pip.

.. code-block:: bash

   python3 -m pip install snakecdysis

Now, follow this documentation to wrapped command line of your favorite workflow !!!!


.. |PythonVersions| image:: https://img.shields.io/badge/python-3.8%2B-blue
   :target: https://www.python.org/downloads
   :alt: Python 3.8+